@@ -7,13 +7,18 @@ import sys
 import logging
 TEST_MESSAGE = logging.debug
 
+TEMP_CONFIG_FILE_NAME=os.path.join(
+	os.path.dirname(
+		os.path.abspath(__file__)),
+	"tempconfig")
+
 # set correct loading path for yapsy's files
-sys.path.append(
+sys.path.insert(0,
 	os.path.dirname(
 		os.path.dirname(
 			os.path.abspath(__file__))))
 
-sys.path.append(
+sys.path.insert(0,
 	os.path.dirname(
 		os.path.dirname(
 			os.path.dirname(
